@@ -418,8 +418,9 @@ class Kweb():
             config = Kconfig()
             k = config.k
             data = request.json or request.forms
-            snapshots = True if data is not None and 'snapshots' in data and bool(data['snapshots']) else False
-            result = k.delete(name, snapshots=snapshots)
+            snapshots = data is not None and 'snapshots' in data and bool(data['snapshots'])
+            keep_disks = data is not None and 'keep_disks' in data and bool(data['keep_disks'])
+            result = k.delete(name, snapshots=snapshots, keep_disks=keep_disks)
             delete_lastvm(name, config.client)
             response.status = 200
             return result
@@ -1257,10 +1258,8 @@ class Kweb():
         self.app = app
         self.port = os.environ.get('KWEB_PORT', 8000)
         self.debug = 'KWEB_DEBUG' in os.environ
-        self.ipv6 = 'KWEB_IPV6' in os.environ
-        self.host = '::' if self.ipv6 else '0.0.0.0'
         self.pull_secret = os.environ.get('PULL_SECRET')
 
     def run(self):
-        data = {'host': self.host, 'port': self.port, 'debug': self.debug}
+        data = {'host': '::', 'port': self.port, 'debug': self.debug}
         self.app.run(**data)
